Overview — A Python Environment for (phylogenetic) Tree Exploration

### Navigation

- index
- modules |
- ETE documentation »

# A Python Environment for (phylogenetic) Tree Exploration

Welcome! This is the documentation for ETE 2.1, last updated Jun 29, 2012.

ETE is a python programming toolkit that assists in the automated manipulation, analysis and visualization of phylogenetic trees. It provides a wide range of tree handling options, node annotation features, programmatic access to the phylomeDB database (containing thousands of pre-calculated phylogenetic trees), and automatic orthology and paralogy detection. In addition, ETE implements an interactive tree visualization system as well as a highly customizable tree drawing engine to create PDF and SVG tree images. Note that, although ETE is mainly developed as a tool for phylogenetic analysis, it can also be used to deal with clustering trees or any other data that can be represented as a hierarchical tree.

If you use ETE to analyze or process results which are planned to be part of a published work, please do not forget to support ETE's development by citing:
Jaime Huerta-Cepas, Joaquín Dopazo and Toni Gabaldón. ETE: a python Environment for Tree Exploration. BMC Bioinformatics 2010, 11:24.

What's new in ETE 2.1? Check older changes Tutorial Comprehensive tutorial with examples Library Reference An index of all ETE functions | Setup and Install ETE install and requirements FAQs Frequently Asked Questions Help Where to find support

Download all examples
Download this documentation as PDF.
For ETE related news and announcements, visit the main ETE website

### Navigation

- index
- modules |
- ETE documentation »